%define gccver %(gcc -dumpversion)
%define MAJver %(echo %version | cut -d. -f1)
%define majver %(echo %version | cut -d. -f1-2)
Name:          compiler-rt
Version:       18.1.8
Release:       2mamba
Summary:       Runtime libraries compiler for clang
Group:         Development/Languages
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://llvm.org/
Source0:       https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/compiler-rt-%{version}.src.tar.xz
Source1:       https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/cmake-%{version}.src.tar.xz
Source2:       https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/llvm-%{version}.src.tar.xz
Source10:      WASI.cmake
Source11:      wasi-toolchain.cmake
License:       NCSA
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libgcc
BuildRequires: libstdc++6-devel
## AUTOBUILDREQ-END
BuildRequires: libwasi-libc-devel
Requires(pre): clang

%description
Runtime libraries compiler for clang.

%debug_package

%prep
%setup -q -c -a0 -a1 -a2
#-D -T
#:<< _EOF
mv compiler-rt-%{version}.src compiler-rt
mv cmake-%{version}.src cmake
mv llvm-%{version}.src llvm

mkdir -p cmake/Platform
cp %{SOURCE10} cmake/Platform

%build
#:<< __EOF
mkdir -p build-wasi
cd build-wasi
cmake ../compiler-rt/lib/builtins -G Ninja \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_C_COMPILER_WORKS=ON \
  -DCMAKE_CXX_COMPILER_WORKS=ON \
  -DCMAKE_MODULE_PATH="$PWD/../make" \
  -DCMAKE_TOOLCHAIN_FILE="%{SOURCE11}" \
  -DCOMPILER_RT_BAREMETAL_BUILD=On \
  -DCOMPILER_RT_INCLUDE_TESTS=OFF \
  -DCOMPILER_RT_HAS_FPIC_FLAG=OFF \
  -DCOMPILER_RT_DEFAULT_TARGET_ONLY=On \
  -DCOMPILER_RT_OS_DIR=wasi \
  -DWASI_SDK_PREFIX=/usr \
  -DCMAKE_C_FLAGS="-fno-exceptions --sysroot=%{_datadir}/wasi-sysroot" \
  -DCMAKE_INSTALL_PREFIX=%{_libdir}/clang/%{MAJver}/ \

ninja

cd ..

mkdir -p build
cd build

cmake ../compiler-rt -G Ninja \
  -DCMAKE_BUILD_TYPE=Release \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DCOMPILER_RT_INSTALL_PATH=%{_libdir}/clang/%{MAJver} \
%ifarch arm
  -DCOMPILER_RT_BUILD_BUILTINS=OFF
%endif

ninja

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

export DESTDIR=%{buildroot}
cd build-wasi
ninja install
cd ..

cd build
ninja install

#mkdir -p %{buildroot}%{_libdir}/clang/%{MAJver}/{lib,share}
#mv %{buildroot}%{_prefix}/lib/linux %{buildroot}%{_libdir}/clang/%{MAJver}/lib/
#mv %{buildroot}%{_prefix}/{share/*.txt,%{_lib}/clang/%{MAJver}/share/}

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%files
%defattr(-,root,root)
%ifarch x86_64 aarch64
%dir %{_libdir}/clang/%{MAJver}/bin
%{_libdir}/clang/%{MAJver}/bin/*
%endif
%dir %{_libdir}/clang/%{MAJver}/include
%{_libdir}/clang/%{MAJver}/include/*
%dir %{_libdir}/clang/%{MAJver}/lib/linux
%{_libdir}/clang/%{MAJver}/lib/linux/*
%dir %{_libdir}/clang/%{MAJver}/lib/wasi
%{_libdir}/clang/%{MAJver}/lib/wasi/libclang_rt.builtins-wasm32.a
%dir %{_libdir}/clang/%{MAJver}/share
%{_libdir}/clang/%{MAJver}/share/*.txt
%doc compiler-rt/LICENSE.TXT

%changelog
* Sat Sep 14 2024 Silvan Calarco <silvan.calarco@mambasoft.it> 18.1.8-2mamba
- rebuilt with wasi support

* Sat Jun 22 2024 Automatic Build System <autodist@openmamba.org> 18.1.8-1mamba
- automatic version update by autodist

* Fri Jun 07 2024 Automatic Build System <autodist@openmamba.org> 18.1.7-1mamba
- automatic version update by autodist

* Sun May 19 2024 Automatic Build System <autodist@openmamba.org> 18.1.6-1mamba
- automatic version update by autodist

* Sat May 04 2024 Automatic Build System <autodist@openmamba.org> 18.1.5-1mamba
- automatic version update by autodist

* Thu Apr 18 2024 Automatic Build System <autodist@openmamba.org> 18.1.4-1mamba
- automatic version update by autodist

* Sat Apr 06 2024 Automatic Build System <autodist@openmamba.org> 18.1.3-1mamba
- automatic version update by autodist

* Wed Mar 20 2024 Automatic Build System <autodist@openmamba.org> 18.1.2-1mamba
- automatic version update by autodist

* Tue Mar 12 2024 Automatic Build System <autodist@openmamba.org> 18.1.1-1mamba
- automatic version update by autodist

* Wed Mar 06 2024 Automatic Build System <autodist@openmamba.org> 18.1.0-1mamba
- automatic version update by autodist

* Tue Nov 28 2023 Automatic Build System <autodist@mambasoft.it> 17.0.6-1mamba
- automatic version update by autodist

* Tue Nov 14 2023 Automatic Build System <autodist@mambasoft.it> 17.0.5-1mamba
- automatic version update by autodist

* Tue Oct 31 2023 Automatic Build System <autodist@mambasoft.it> 17.0.4-1mamba
- automatic version update by autodist

* Sun Oct 22 2023 Automatic Build System <autodist@mambasoft.it> 17.0.3-1mamba
- automatic version update by autodist

* Sat Aug 05 2023 Silvan Calarco <silvan.calarco@mambasoft.it> 16.0.6-2mamba
- set COMPILER_RT_INSTALL_PATH=%{_libdir}/clang/%{MAJver}

* Wed Jun 14 2023 Automatic Build System <autodist@mambasoft.it> 16.0.6-1mamba
- automatic version update by autodist

* Sat Jun 03 2023 Automatic Build System <autodist@mambasoft.it> 16.0.5-1mamba
- automatic version update by autodist

* Thu May 18 2023 Automatic Build System <autodist@mambasoft.it> 16.0.4-1mamba
- automatic version update by autodist

* Wed May 03 2023 Automatic Build System <autodist@mambasoft.it> 16.0.3-1mamba
- automatic version update by autodist

* Thu Apr 20 2023 Automatic Build System <autodist@mambasoft.it> 16.0.2-1mamba
- automatic version update by autodist

* Wed Apr 05 2023 Automatic Build System <autodist@mambasoft.it> 16.0.1-1mamba
- automatic version update by autodist

* Sat Mar 18 2023 Automatic Build System <autodist@mambasoft.it> 16.0.0-1mamba
- automatic version update by autodist

* Thu Jan 12 2023 Automatic Build System <autodist@mambasoft.it> 15.0.7-1mamba
- automatic version update by autodist

* Tue Nov 29 2022 Automatic Build System <autodist@mambasoft.it> 15.0.6-1mamba
- automatic version update by autodist

* Wed Nov 23 2022 Automatic Build System <autodist@mambasoft.it> 15.0.5-1mamba
- automatic version update by autodist

* Sat Jun 25 2022 Automatic Build System <autodist@mambasoft.it> 14.0.6-1mamba
- automatic version update by autodist

* Sat Jun 11 2022 Automatic Build System <autodist@mambasoft.it> 14.0.5-1mamba
- automatic version update by autodist

* Wed May 25 2022 Automatic Build System <autodist@mambasoft.it> 14.0.4-1mamba
- automatic version update by autodist

* Sat Apr 30 2022 Automatic Build System <autodist@mambasoft.it> 14.0.3-1mamba
- automatic version update by autodist

* Wed Apr 27 2022 Automatic Build System <autodist@mambasoft.it> 14.0.2-1mamba
- automatic version update by autodist

* Wed Apr 13 2022 Automatic Build System <autodist@mambasoft.it> 14.0.1-1mamba
- automatic version update by autodist

* Thu Mar 24 2022 Automatic Build System <autodist@mambasoft.it> 14.0.0-1mamba
- automatic version update by autodist

* Thu Feb 03 2022 Automatic Build System <autodist@mambasoft.it> 13.0.1-1mamba
- automatic version update by autodist

* Sat Oct 30 2021 Automatic Build System <autodist@mambasoft.it> 13.0.0-1mamba
- automatic version update by autodist

* Mon Mar 01 2021 Automatic Build System <autodist@mambasoft.it> 11.1.0-1mamba
- automatic version update by autodist

* Mon Jan 11 2021 Automatic Build System <autodist@mambasoft.it> 11.0.1-1mamba
- automatic version update by autodist

* Tue Oct 13 2020 Automatic Build System <autodist@mambasoft.it> 11.0.0-1mamba
- automatic version update by autodist

* Sat Jul 25 2020 Automatic Build System <autodist@mambasoft.it> 10.0.1-1mamba
- automatic version update by autodist

* Thu Apr 02 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 10.0.0-1mamba
- update to 10.0.0

* Sat Feb 15 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 9.0.1-3mamba
- rebuilt apart from llvm

* Tue Jan 07 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 9.0.1-2mamba
- rebuild with -DLLVM_ENABLE_LTO=Thin

* Mon Dec 30 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 9.0.1-1mamba
- update to 9.0.1

* Thu Mar 28 2019 Automatic Build System <autodist@mambasoft.it> 8.0.0-1mamba
- automatic version update by autodist

* Sat Jan 26 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 7.0.1-4mamba
- bump release

* Sat Jan 26 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 7.0.1-3mamba
- move *.so from libllvm-devel to libllvm

* Mon Jan 21 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 7.0.1-2mamba
- rebuilt with binutils plugin LLVMgold.so

* Sat Dec 22 2018 Automatic Build System <autodist@mambasoft.it> 7.0.1-1mamba
- automatic version update by autodist

* Sun Oct 14 2018 Automatic Build System <autodist@mambasoft.it> 7.0.0-1mamba
- automatic version update by autodist

* Sun Sep 02 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 6.0.1-4mamba
- remove building with libc++ to fix e.g. Mesa build

* Sat Jul 14 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 6.0.1-3mamba
- rebuilt wth LLVM_ENABLE_LIBCXX=ON

* Sat Jul 14 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 6.0.1-2mamba
- rebuilt with libc++

* Sat Jul 07 2018 Automatic Build System <autodist@mambasoft.it> 6.0.1-1mamba
- automatic version update by autodist

* Mon Jun 25 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 6.0.0-4mamba
- rebuilt with gcc 8.1.0

* Sun Jun 24 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 6.0.0-3mamba
- apply patches from Arch to possibly fix lld segfault

* Sat Jun 23 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 6.0.0-2mamba
- rebuilt with standard target libdir and other changes to try fixing lld crash with at least chromium build

* Tue Jun 19 2018 Automatic Build System <autodist@mambasoft.it> 6.0.0-1mamba
- automatic version update by autodist

* Mon Dec 25 2017 Automatic Build System <autodist@mambasoft.it> 5.0.1-1mamba
- automatic version update by autodist

* Tue Nov 28 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 5.0.0-2mamba
- fix link against libllvm by changing and extending build arguments and external llvm subpackages

* Tue Nov 28 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 5.0.0-1mamba
- update to 5.0.0

* Wed Jul 13 2016 Automatic Build System <autodist@mambasoft.it> 3.8.1-1mamba
- automatic version update by autodist

* Sat Jun 11 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.0-3mamba
- rebuilt using cmake

* Sat May 28 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 3.8.0-2mamba
- rebuilt

* Thu May 26 2016 Automatic Build System <autodist@mambasoft.it> 3.8.0-1mamba
- automatic version update by autodist

* Sun Jan 18 2015 Automatic Build System <autodist@mambasoft.it> 3.5.1-1mamba
- automatic version update by autodist

* Fri Sep 19 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.5.0-2mamba
- patch llvm-config for x86_64 support and %{_libdir}/llvm

* Wed Sep 10 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.5.0-1mamba
- update to 3.5.0

* Thu Jul 10 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4.2-1mamba
- update to 3.4.2

* Sun Feb 16 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4-2mamba
- fix configure settings and add --with-extra-ld-options to correctly link and
  pass --with-arch=%{_target_cpu} to fix penmamba bug #000163

* Sun Jan 12 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 3.4-1mamba
- update to 3.4

* Thu Jun 20 2013 Automatic Build System <autodist@mambasoft.it> 3.3-1mamba
- update to 3.3

* Sat Dec 22 2012 Automatic Build System <autodist@mambasoft.it> 3.2-1mamba
- automatic version update by autodist

* Fri Jul 20 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 3.1-1mamba
- update to 3.1

* Thu Feb 23 2012 Ercole 'ercolinux' Carpanetto <ercole69@gmail.com> 3.0.-1mamba
- update to 3.0

* Sun Jul 10 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 2.9-1mamba
- update to 2.9

* Sat Jan 01 2011 Davide Madrisan <davide.madrisan@gmail.com> 2.8-1mamba
- package created by autospec
